@@ -1,13 +1,11 @@
 # -*- coding: utf-8 -*-
-"""
-Provides access to the configuration directory of pyTEMlib
-"""
-
 # Gleaned from
 # Copyright © 2007 Francisco Javier de la Peña
 # file of EELSLab.
 #
-
+"""
+config_dir: setup of directory ~/.pyTEMlib for custom sources and database
+"""
 import os
 import shutil
 
