@@ -1,17 +1,14 @@
-##################################
-#
-# image_tools.py
-# by Gerd Duscher, UTK
-# part of pyTEMlib
-# MIT license except where stated differently
-#
-###############################
+"""
+image_tools.py
+by Gerd Duscher, UTK
+part of pyTEMlib
+MIT license except where stated differently
+"""
+
 import numpy as np
 
 import matplotlib as mpl
 import matplotlib.pylab as plt
-from matplotlib.patches import Polygon  # plotting of polygons -- graph rings
-
 import matplotlib.widgets as mwidgets
 from matplotlib.widgets import RectangleSelector
 
@@ -63,32 +60,111 @@ def get_wavelength(e0):
     """
     Calculates the relativistic corrected de Broglie wave length of an electron
 
-    Input:
-    ------
-        acceleration voltage in volt
-    Output:
+    Parameters
+    ----------
+    e0: float
+      acceleration voltage in volt
+
+    Returns
     -------
-        wave length in 1/nm
+    wave length in 1/nm
     """
 
     eV = const.e * e0
     return const.h/np.sqrt(2*const.m_e*eV*(1+eV/(2*const.m_e*const.c**2)))*10**9
 
+def read_image_info(dataset):
+    """Updates dataset.metadata['experiment'] with essential information read from original metadata
+
+    This depends on whether it is originally a nion or a dm3 file
+    """
+    if not isinstance(dataset, sidpy.Dataset):
+        raise TypeError("we need a sidpy.Dataset")
+
+    if 'metadata' in dataset.original_metadata:
+        if 'hardware_source' in dataset.original_metadata['metadata']:
+            experiment_dictionary = read_nion_image_info(dataset.original_metadata)
+    if 'DM' in dataset.original_metadata:
+        experiment_dictionary = read_dm3_image_info(dataset.original_metadata)
+    if 'experiment' not in dataset.metadata:
+         dataset.metadata['experiment'] = {}
+    dataset.metadata['experiment'].update(experiment_dictionary)
+
+def read_dm3_image_info(original_metadata):
+    """Read essential parameter from original_metadata originating from a dm3 file"""
+    if not isinstance(original_metadata, dict):
+        raise TypeError('We need a dictionary to read')
+
+    if 'DM' not in original_metadata:
+        return {}
+    main_image = original_metadata['DM']['chosen_image']
+    exp_dictionary = original_metadata['ImageList'][str(main_image)]['ImageTags']
+    experiment = {}
+
+    if 'Acquisition' in exp_dictionary:
+        if 'Parameters' in exp_dictionary['Acquisition']:
+            if 'High Level' in exp_dictionary['Acquisition']['Parameters']:
+                if 'Exposure (s)' in exp_dictionary['Acquisition']['Parameters']['High Level']:
+                    experiment['exposure_time'] = exp_dictionary['Acquisition']['Parameters']['High Level'][
+                        'Exposure (s)']
+
+    if 'Microscope Info' in exp_dictionary:
+        if 'Microscope' in exp_dictionary['Microscope Info']:
+            experiment['microscope'] = exp_dictionary['Microscope Info']['Microscope']
+        if 'Voltage' in exp_dictionary['Microscope Info']:
+            experiment['acceleration_voltage'] = exp_dictionary['Microscope Info']['Voltage']
+        if 'Illumination Mode' in exp_dictionary['Microscope Info']:
+            if exp_dictionary['Microscope Info']['Illumination Mode'] == 'TEM':
+                experiment['convergence_angle'] = 0.0
+                experiment['collection_angle'] = 100.0
+            if exp_dictionary['Microscope Info']['Illumination Mode'] == 'SPOT':
+                experiment['convergence_angle'] = 10.0
+                experiment['collection_angle'] = 50.0
+    return experiment
+
+
+def read_nion_image_info(original_metadata):
+    """Read essential parameter from original_metadata originating from a dm3 file"""
+    if not isinstance(original_metadata, dict):
+        raise TypeError('We need a dictionary to read')
+    if 'metadata' not in original_metadata:
+        return {}
+    if 'hardware_source' not in original_metadata['metadata']:
+        return {}
+    if 'ImageScanned' not in original_metadata['metadata']['hardware_source']:
+        return {}
+
+    exp_dictionary = original_metadata['metadata']['hardware_source']['ImageScanned']
+    experiment = {}
+    print(exp_dictionary)
+    if 'autostem' in exp_dictionary:
+        print('auto')
+
+    print(exp_dictionary.keys())
+    print()
+
+    print(experiment)
+
 
 def fourier_transform(dset):
     """
         Reads information into dictionary 'tags', performs 'FFT', and provides a smoothed FT and reciprocal
         and intensity limits for visualization.
 
-        Input
-        -----
+        Parameters
+        ----------
         dset: sidpy.Dataset
+            image
 
-        Usage
-        -----
+        Returns
+        -------
+        fft_dset: sidpy.Dataset
+            Fourier transform with correct dimensions
 
-        fft_dataset = fourier_transform(sidpy_dataset)
-        fft+dataset.plot()
+        Example
+        -------
+        >>> fft_dataset = fourier_transform(sidpy_dataset)
+        >>> fft_dataset.plot()
     """
 
     assert isinstance(dset, sidpy.Dataset), 'Expected a sidpy Dataset'
@@ -119,9 +195,6 @@ def fourier_transform(dset):
     fft_transform = (np.fft.fftshift(np.fft.fft2(image)))
 
     image_dims = get_image_dims(dset)
-    extent = dset.get_extent(image_dims)
-    scale_x = 1 / abs(extent[1] - extent[0])
-    scale_y = 1 / abs(extent[2] - extent[3])
 
     units_x = '1/' + dset._axes[image_dims[0]].units
     units_y = '1/' + dset._axes[image_dims[1]].units
@@ -132,10 +205,12 @@ def fourier_transform(dset):
     fft_dset.data_type = 'IMAGE'
     fft_dset.source = dset.title
     fft_dset.modality = 'fft'
-    fft_dset.set_dimension(0, sidpy.Dimension((np.arange(fft_dset.shape[0]) - fft_dset.shape[0] / 2) * scale_x,
+
+    fft_dset.set_dimension(0, sidpy.Dimension(np.fft.fftshift(np.fft.fftfreq(image.shape[0], d=get_slope(dset.x.values))),
+
                                               name='u', units=units_x, dimension_type='RECIPROCAL',
                                               quantity='reciprocal_length'))
-    fft_dset.set_dimension(1, sidpy.Dimension((np.arange(fft_dset.shape[1]) - fft_dset.shape[1] / 2) * scale_y,
+    fft_dset.set_dimension(1, sidpy.Dimension(np.fft.fftshift(np.fft.fftfreq(image.shape[1], d=get_slope(dset.y.values))),
                                               name='v', units=units_y, dimension_type='RECIPROCAL',
                                               quantity='reciprocal_length'))
 
@@ -146,21 +221,20 @@ def power_spectrum(dset, smoothing=3):
     """
     Calculate power spectrum
 
-    Input:
-    ------
-            channel: channnel in h5f file with image content
+    Parameters
+    ----------
+    dset: sidpy.Dataset
+        image
+    smoothing: int
+        Gaussian smoothing
 
-    Output:
+    Returns
     -------
-            tags: dictionary with
-                ['data']: fourier transformed image
-                ['axis']: scale of reciprocal image
-                ['power_spectrum']: power_spectrum
-                ['FOV']: field of view for extent parameter in plotting
-                ['minimum_intensity']: suggested minimum intensity for plotting
-                ['maximum_intensity']: suggested maximum intensity for plotting
+    power_spec: sidpy.Dataset
+        power spectrum with correct dimensions
 
     """
+
     fft_transform = fourier_transform(dset)
     fft_mag = np.abs(fft_transform)
     fft_mag2 = ndimage.gaussian_filter(fft_mag, sigma=(smoothing, smoothing), order=0)
@@ -168,8 +242,7 @@ def power_spectrum(dset, smoothing=3):
     power_spec = fft_transform.like_data(np.log(1.+fft_mag2))
 
     # prepare mask
-
-    x, y = np.meshgrid(power_spec.u.values, power_spec.v.values)
+    x, y = np.meshgrid(power_spec.v.values, power_spec.u.values)
     mask = np.zeros(power_spec.shape)
 
     mask_spot = x ** 2 + y ** 2 > 1 ** 2
@@ -179,49 +252,49 @@ def power_spectrum(dset, smoothing=3):
 
     mask[np.where(mask == 1)] = 0  # just in case of overlapping disks
 
-    # minimum_intensity = np.log2(1 + fft_mag2)[np.where(mask == 2)].min() * 0.95
-    # maximum_intensity = np.log2(1 + fft_mag2)[np.where(mask == 2)].max() * 1.05
-    power_spec.metadata = {'smoothing': smoothing}
-    #                       'minimum_intensity': minimum_intensity, 'maximum_intensity': maximum_intensity}
+    minimum_intensity = np.array(power_spec)[np.where(mask == 2)].min() * 0.95
+    maximum_intensity = np.array(power_spec)[np.where(mask == 2)].max() * 1.05
+    power_spec.metadata = {'fft': {'smoothing': smoothing,
+                                   'minimum_intensity': minimum_intensity, 'maximum_intensity': maximum_intensity}}
     power_spec.title = 'power spectrum ' + power_spec.source
 
     return power_spec
 
 
 def diffractogram_spots(dset, spot_threshold):
-    """
-    Find spots in diffractogram and sort them by distance from center
+    """Find spots in diffractogram and sort them by distance from center
 
-    Input:
-    ------
-            fft_tags: dictionary with
-                ['spatial_***']: information of scale of fourier pattern
-                ['data']: power_spectrum
-            spot_threshold: threshold for blob finder
-    Output:
+    Uses blob_log from scipy.spatial
+
+    Parameters
+    ----------
+    dset: sidpy.Dataset
+        diffratogram
+    spot_threshold: float
+        threshold for blob finder
+
+    Returns
     -------
-            spots: numpy array with sorted position (x,y) and radius (r) of all spots
-
+    spots: numpy array
+        sorted position (x,y) and radius (r) of all spots
     """
-    # Needed for conversion from pixel to Reciprocal space
-    # we'll have to switch x- and y-coordinates due to the differences in numpy and matrix
-    center = np.array([int(dset.shape[0]/2.), int(dset.shape[1]/2.), 1])
-    rec_scale = np.array([get_slope(dset.u.values), get_slope(dset.v.values), 1])
 
-    # spot detection ( for future referece there is no symmetry assumed here)
-    data = np.array(np.log(1+np.abs(dset))).T
+    # spot detection (for future reference there is no symmetry assumed here)
+    data = np.array(np.log(1+np.abs(dset)))
     data = (data - data.min())
     data = data/data.max()
     # some images are strange and blob_log does not work on the power spectrum
     try:
-        spots_random = (blob_log(data, max_sigma=5, threshold=spot_threshold) - center) * rec_scale
+        spots_random = blob_log(data, max_sigma=5, threshold=spot_threshold)
     except ValueError:
-        spots_random = (peak_local_max(np.array(data.T), min_distance=3, threshold_rel=spot_threshold) - center[:2]) \
-                       * rec_scale
+        spots_random = peak_local_max(np.array(data.T), min_distance=3, threshold_rel=spot_threshold)
         spots_random = np.hstack(spots_random, np.zeros((spots_random.shape[0], 1)))
 
     print(f'Found {spots_random.shape[0]} reflections')
 
+    # Needed for conversion from pixel to Reciprocal space
+    rec_scale = np.array([get_slope(dset.u.values), get_slope(dset.v.values)])
+    spots_random[:, :2] = spots_random[:, :2]*rec_scale+[dset.u.values[0], dset.v.values[0]]
     # sort reflections
     spots_random[:, 2] = np.linalg.norm(spots_random[:, 0:2], axis=1)
     spots_index = np.argsort(spots_random[:, 2])
@@ -235,32 +308,36 @@ def adaptive_fourier_filter(dset, spots, low_pass=3, reflection_radius=0.3):
     """
     Use spots in diffractogram for a Fourier Filter
 
-    Input:
-    ------
-            image:  image to be filtered
-            tags: dictionary with
-                ['spatial_***']: information of scale of fourier pattern
-                ['spots']: sorted spots in diffractogram in 1/nm
-            low_pass: low pass filter in center of diffractogrm
+    Parameters
+    ----------
+    dset: sidpu.Dataset
+        image to be filtered
+    spots: np.ndarray(N,2)
+        sorted spots in diffractogram in 1/nm
+    low_pass:  float
+        low pass filter in center of diffractogram in 1/nm
+    reflection_radius:  float
+        radius of masked reflections in 1/nm
 
     Output:
     -------
             Fourier filtered image
     """
-    # prepare mask
 
+    if not isinstance(dset, sidpy.Dataset):
+        raise TypeError('We need a sidpy.Dataset')
     fft_transform = fourier_transform(dset)
+
+    # prepare mask
     x, y = np.meshgrid(fft_transform.u.values, fft_transform.v.values)
     mask = np.zeros(dset.shape)
 
     # mask reflections
-    # reflection_radius = 0.3 # in 1/nm
     for spot in spots:
         mask_spot = (x - spot[0]) ** 2 + (y - spot[1]) ** 2 < reflection_radius ** 2  # make a spot
         mask = mask + mask_spot  # add spot to mask
 
     # mask zero region larger (low-pass filter = intensity variations)
-    # low_pass = 3 # in 1/nm
     mask_spot = x ** 2 + y ** 2 < low_pass ** 2
     mask = mask + mask_spot
     mask[np.where(mask > 1)] = 1
@@ -271,11 +348,12 @@ def adaptive_fourier_filter(dset, spots, low_pass=3, reflection_radius=0.3):
     filtered_image.source = dset.title
     filtered_image.metadata = {'analysis': 'adaptive fourier filtered', 'spots': spots,
                                'low_pass': low_pass, 'reflection_radius': reflection_radius}
-
     return filtered_image
 
 
 def rotational_symmetry_diffractogram(spots):
+    """ Test rotational symmetry of diffraction spots"""
+
     rotation_symmetry = []
     for n in [2, 3, 4, 6]:
         cc = np.array(
@@ -297,7 +375,29 @@ def rotational_symmetry_diffractogram(spots):
 
 
 def complete_registration(main_dataset, storage_channel=None):
-    """Rigid and then non-rigid (demon) registration"""
+    """Rigid and then non-rigid (demon) registration
+
+    Performs rigid and then non-rigid registration, please see individual functions:
+    - rigid_registration
+    - demon_registration
+
+    Parameters
+    ----------
+    main_dataset: sidpy.Dataset
+        dataset of data_type 'IMAGE_STACK' to be registered
+
+    Returns
+    -------
+    non_rigid_registered: sidpy.Dataset
+    rigid_registered_dataset: sidpy.Dataset
+
+    """
+
+    if not isinstance(main_dataset, sidpy.Dataset):
+        raise TypeError('We need a sidpy.Dataset')
+    if main_dataset.data_type.name != 'IMAGE_STACK':
+        raise TypeError('Registration makes only sense for an image stack')
+
     rigid_registered_dataset = rigid_registration(main_dataset)
     if storage_channel is None:
         storage_channel = main_dataset.h5_dataset.parent.parent
@@ -316,9 +416,12 @@ def demon_registration(dataset, verbose=False):
     """
     Diffeomorphic Demon Non-Rigid Registration
 
-    Usage:
-    ------
-    dem_reg = demon_reg(cube, verbose = False)
+    Depends on:
+        simpleITK and numpy
+    Please Cite: http://www.simpleitk.org/SimpleITK/project/parti.html
+    and T. Vercauteren, X. Pennec, A. Perchant and N. Ayache
+    Diffeomorphic Demons Using ITK\'s Finite Difference Solver Hierarchy
+    The Insight Journal, http://hdl.handle.net/1926/510 2007
 
     Parameters
     ----------
@@ -330,15 +433,16 @@ def demon_registration(dataset, verbose=False):
     -------
         dem_reg: stack of images with non-rigid registration
 
-    Depends on:
-        simpleITK and numpy
-
-    Please Cite: http://www.simpleitk.org/SimpleITK/project/parti.html
-    and T. Vercauteren, X. Pennec, A. Perchant and N. Ayache
-    Diffeomorphic Demons Using ITK\'s Finite Difference Solver Hierarchy
-    The Insight Journal, http://hdl.handle.net/1926/510 2007
+    Example
+    -------
+    dem_reg = demon_reg(stack_dataset, verbose=False)
     """
 
+    if not isinstance(dataset, sidpy.Dataset):
+        raise TypeError('We need a sidpy.Dataset')
+    if dataset.data_type.name != 'IMAGE_STACK':
+        raise TypeError('Registration makes only sense for an image stack')
+
     dem_reg = np.zeros(dataset.shape)
     nimages = dataset.shape[0]
     if verbose:
@@ -383,7 +487,6 @@ def demon_registration(dataset, verbose=False):
         resampler.SetTransform(out_tx)
         out = resampler.Execute(moving)
         dem_reg[i, :, :] = sITK.GetArrayFromImage(out)
-        # print('image ', i)
 
     if QT_available:
         progress.close()
@@ -409,20 +512,26 @@ def demon_registration(dataset, verbose=False):
 def rigid_registration(dataset):
     """
     Rigid registration of image stack with sub-pixel accuracy
-    used phase_cross_correlation from skimage.registration
+
+    Uses phase_cross_correlation from skimage.registration
     (we determine drift from one image to next)
 
     Parameters
     ----------
-    dataset: sidpy.Datset
+    dataset: sidpy.Dataset
         sidpy dataset with image_stack dataset
 
     Returns
     -------
-    Registered Stack and drift (with respect to center image)
-
+    rigid_registered: sidpy.Dataset
+        Registered Stack and drift (with respect to center image)
     """
 
+    if not isinstance(dataset, sidpy.Dataset):
+        raise TypeError('We need a sidpy.Dataset')
+    if dataset.data_type.name != 'IMAGE_STACK':
+        raise TypeError('Registration makes only sense for an image stack')
+
     nopix = dataset.shape[1]
     nopiy = dataset.shape[2]
     nimages = dataset.shape[0]
@@ -475,16 +584,24 @@ def rigid_registration(dataset):
 
 
 def rig_reg_drift(dset, rel_drift):
-    """
-    Uses relative drift to shift images ontop of each other
-    Shifting is done with shift routine of ndimage from scipy
+    """ Shifting images on top of each other
 
-    is used by Rigid_Registration routine
+    Uses relative drift to shift images on top of each other,
+    with center image as reference.
+    Shifting is done with shift routine of ndimage from scipy.
+    This function is used by rigid_registration routine
 
-    Input image_channel with image_stack numpy array
-    relative_drift from image to image as list of [shiftx, shifty]
+    Parameters
+    ----------
+    dset: sidpy.Dataset
+        dataset with image_stack
+    rel_drift:
+        relative_drift from image to image as list of [shiftx, shifty]
 
-    output stack and drift
+    Returns
+    -------
+    stack: numpy array
+    drift: list of drift in pixel
     """
 
     rig_reg = np.zeros(dset.shape)
@@ -504,9 +621,19 @@ def rig_reg_drift(dset, rel_drift):
 
 
 def crop_image_stack(rig_reg, drift):
+    """Crop images in stack according to drift
+
+    This function is used by rigid_registration routine
+
+    Parameters
+    ----------
+    rig_reg: numpy array (N,x,y)
+    drift: list (2,B)
+
+    Returns:
+    numpy array
     """
-    ## Crop images
-    """
+
     xpmin = int(-np.floor(np.min(np.array(drift)[:, 0])))
     xpmax = int(rig_reg.shape[1] - np.ceil(np.max(np.array(drift)[:, 0])))
     ypmin = int(-np.floor(np.min(np.array(drift)[:, 1])))
@@ -516,6 +643,8 @@ def crop_image_stack(rig_reg, drift):
 
 
 class ImageWithLineProfile:
+    """Image with line profile"""
+
     def __init__(self, data, extent, title=''):
         fig, ax = plt.subplots(1, 1)
         self.figure = fig
@@ -584,6 +713,7 @@ class ImageWithLineProfile:
         
 
 def histogram_plot(image_tags):
+    """interactive histogram"""
     nbins = 75
     color_map_list = ['gray', 'viridis', 'jet', 'hot']
     
@@ -668,6 +798,7 @@ def histogram_plot(image_tags):
 
 
 def clean_svd(im, pixel_size=1, source_size=5):
+    """De-noising of image by using first component of single value decomposition"""
     patch_size = int(source_size/pixel_size)
     if patch_size < 3:
         patch_size = 3
@@ -689,45 +820,79 @@ def rebin(im, binning=2):
     """
     rebin an image by the number of pixels in x and y direction given by binning
     
-    Input:
-    ------
-            image: numpy array in 2 dimensions
+    Parameter
+    ---------
+    image: numpy array in 2 dimensions
     
-    Output:
+    Returns
     -------
-            binned image 
+    binned image as numpy array
     """
     if len(im.shape) == 2:
         return im.reshape((im.shape[0]//binning, binning, im.shape[1]//binning, binning)).mean(axis=3).mean(1)
     else:
-        print('not a 2D image')
+        raise TypeError('not a 2D image')
         return im
 
 
 def cart2pol(points):
+    """Cartesian to polar coordinate conversion
+
+    Parameters
+    ---------
+    points: float or numpy array
+        points to be converted (Nx2)
+
+    Returns
+    -------
+    rho: float or numpy array
+        distance
+    phi: float or numpy array
+        angle
+    """
+
     rho = np.linalg.norm(points[:, 0:2], axis=1)
     phi = np.arctan2(points[:, 1], points[:, 0])
     return rho, phi
 
 
 def pol2cart(rho, phi):
+    """Polar to Cartesian coordinate conversion
+
+    Parameters
+    ----------
+    rho: float or numpy array
+        distance
+    phi: float or numpy array
+        angle
+
+    Returns
+    -------
+    x: float or numpy array
+        x coordinates of converted points(Nx2)
+    """
+
     x = rho * np.cos(phi)
     y = rho * np.sin(phi)
     return x, y
 
 
 def xy2polar(points, rounding=1e-3):
-    """
-    Conversion from carthesian to polar coordinates
+    """ Conversion from carthesian to polar coordinates
     
     the angles and distances are sorted by r and then phi
     The indices of this sort is also returned
     
-    input points: numpy array with number of points in axis 0 first two elements in axis 1 are x and y
+    Parameters
+    ----------
+    points: numpy array
+        number of points in axis 0 first two elements in axis 1 are x and y
+    rounding: int
+        optional rounding in significant digits
     
-    optional rounding in significant digits 
-    
-    returns r,phi, sorted_indices
+    Returns
+    -------
+    r, phi, sorted_indices
     """
     
     r, phi = cart2pol(points)
@@ -743,6 +908,10 @@ def xy2polar(points, rounding=1e-3):
             
 
 def cartesian2polar(x, y, grid, r, t, order=3):
+    """Transform cartesian grid to polar grid
+
+    Used by warp
+    """
 
     rr, tt = np.meshgrid(r, t)
 
@@ -759,6 +928,8 @@ def cartesian2polar(x, y, grid, r, t, order=3):
 
 
 def warp(diff, center):
+    """Convert diffraction pattern to polar coordinates"""
+
     # Define original polar grid
     nx = diff.shape[0]
     ny = diff.shape[1]
@@ -778,7 +949,24 @@ def warp(diff, center):
 
 def calculate_ctf(wavelength, cs, defocus, k):
     """ Calculate Contrast Transfer Function
+
     everything in nm
+
+    Parameters
+    ----------
+    wavelength: float
+        deBroglie wavelength of electrons
+    cs: float
+        spherical aberration coefficient
+    defocus: float
+        defocus
+    k: numpy array
+        reciprocal scale
+
+    Returns:
+    ctf: numpy array
+        contrast transfer function
+
     """
     ctf = np.sin(np.pi*defocus*wavelength*k**2+0.5*np.pi*cs*wavelength**3*k**4)
     return ctf
@@ -787,13 +975,15 @@ def calculate_ctf(wavelength, cs, defocus, k):
 def calculate_scherzer(wavelength, cs):
     """
     Calculate the Scherzer defocus. Cs is in mm, lambda is in nm
-    # EInput and output in nm
+
+    # Input and output in nm
     """
     scherzer = -1.155*(cs*wavelength)**0.5  # in m
     return scherzer
 
 
 def calibrate_image_scale(fft_tags, spots_reference, spots_experiment):
+    """depreciated get change of scale from comparison of spots to Bragg angles """
     gx = fft_tags['spatial_scale_x']
     gy = fft_tags['spatial_scale_y']
 
@@ -809,11 +999,13 @@ def calibrate_image_scale(fft_tags, spots_reference, spots_experiment):
         return np.sqrt((xdata * dgx) ** 2 + (ydata * dgy) ** 2) - dist_reference.min()
 
     x0 = [1.001, 0.999]
-    dg, sig = optimization.leastsq(func, x0, args=(closest_exp_reflections[:, 0], closest_exp_reflections[:, 1]))
+    [dg, sig] = optimization.leastsq(func, x0, args=(closest_exp_reflections[:, 0], closest_exp_reflections[:, 1]))
     return dg
 
 
 def align_crystal_reflections(spots, crystals):
+    """ Depreciated - use diffraction spots"""
+
     crystal_reflections_polar = []
     angles = []
     exp_r, exp_phi = cart2pol(spots)  # just in polar coordinates
